==> kadu_3.0~rc1.orig.tar.bz2: kadu-3.0-rc1/plugins/gadu_protocol/services/gadu-buddy-list-serialization-service.cpp <==
/*
 * %kadu copyright begin%
 * Copyright 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
 * %kadu copyright end%
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#include "gadu-buddy-list-serialization-service.h"

#include "buddies/buddy-list.h"

#include "helpers/gadu-list-helper.h"

GaduBuddyListSerializationService::GaduBuddyListSerializationService(Account account, QObject *parent) :
		BuddyListSerializationService{account, parent}
{
}

GaduBuddyListSerializationService::~GaduBuddyListSerializationService()
{
}

BuddyList GaduBuddyListSerializationService::deserialize(QTextStream &dataStream)
{
	return GaduListHelper::streamToBuddyList(account(), dataStream);
}

QByteArray GaduBuddyListSerializationService::serialize(const BuddyList &buddies)
{
	return GaduListHelper::buddyListToByteArray(account(), buddies);
}

#include "moc_gadu-buddy-list-serialization-service.cpp"

==> kadu_4.1.orig.tar.bz2: kadu-4.1/plugins/gadu_protocol/services/gadu-buddy-list-serialization-service.cpp <==
/*
 * %kadu copyright begin%
 * Copyright 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
 * %kadu copyright end%
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#include "gadu-buddy-list-serialization-service.h"

#include "buddies/buddy-list.h"

#include "helpers/gadu-list-helper.h"

GaduBuddyListSerializationService::GaduBuddyListSerializationService(GaduListHelper *gaduListHelper, Account account, QObject *parent) :
		BuddyListSerializationService{account, parent},
		m_gaduListHelper{gaduListHelper}
{
}

GaduBuddyListSerializationService::~GaduBuddyListSerializationService()
{
}

BuddyList GaduBuddyListSerializationService::deserialize(QTextStream &dataStream)
{
	return m_gaduListHelper->streamToBuddyList(account(), dataStream);
}

QByteArray GaduBuddyListSerializationService::serialize(const BuddyList &buddies)
{
	return m_gaduListHelper->buddyListToByteArray(account(), buddies);
}

#include "moc_gadu-buddy-list-serialization-service.cpp"
